@@ -38,7 +38,6 @@ describe 'octavia' do
           :rabbit_ha_queues                => '<SERVICE DEFAULT>',
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
           :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
@@ -49,11 +48,15 @@ describe 'octavia' do
           :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
           :kombu_compression               => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :amqp_auto_delete                => '<SERVICE DEFAULT>',
           :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
           :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+          :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :use_queue_manager               => '<SERVICE DEFAULT>',
+          :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
           :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
         )
         should contain_oslo__messaging__notifications('octavia_config').with(
@@ -63,15 +66,17 @@ describe 'octavia' do
           :retry         => '<SERVICE DEFAULT>',
         )
       end
-    end
 
-    it 'has default RPC topic' do
-      is_expected.to contain_octavia_config('oslo_messaging/topic').with_value('octavia-rpc')
+      it 'configures defaults' do
+        is_expected.to contain_octavia_config('DEFAULT/host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_octavia_config('oslo_messaging/topic').with_value('octavia-rpc')
+      end
     end
 
     context 'with overridden parameters' do
       let :params do
         {
+          :host                               => 'localhost',
           :default_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout               => '120',
           :control_exchange                   => 'octavia',
@@ -79,18 +84,21 @@ describe 'octavia' do
           :rabbit_ha_queues                   => true,
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
-          :rabbit_heartbeat_in_pthread        => true,
           :rabbit_qos_prefetch_count          => 0,
           :rabbit_quorum_queue                => true,
           :rabbit_transient_quorum_queue      => true,
+          :rabbit_transient_queues_ttl        => 60,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_use_queue_manager           => true,
+          :rabbit_stream_fanout               => true,
           :rabbit_enable_cancel_on_failover   => false,
           :kombu_compression                  => 'gzip',
           :kombu_reconnect_delay              => '5.0',
           :kombu_failover_strategy            => 'shuffle',
           :amqp_durable_queues                => true,
+          :amqp_auto_delete                   => true,
           :package_ensure                     => '2012.1.1-15.el6',
           :notification_transport_url         => 'rabbit://rabbit_user:password@localhost:5673',
           :notification_driver                => 'ceilometer.compute.octavia_notifier',
@@ -111,7 +119,6 @@ describe 'octavia' do
           :rabbit_ha_queues                => true,
           :heartbeat_timeout_threshold     => '60',
           :heartbeat_rate                  => '10',
-          :heartbeat_in_pthread            => true,
           :rabbit_qos_prefetch_count       => 0,
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '5.0',
@@ -122,11 +129,15 @@ describe 'octavia' do
           :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
           :kombu_compression               => 'gzip',
           :amqp_durable_queues             => true,
+          :amqp_auto_delete                => true,
           :rabbit_quorum_queue             => true,
           :rabbit_transient_quorum_queue   => true,
+          :rabbit_transient_queues_ttl     => 60,
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
+          :use_queue_manager               => true,
+          :rabbit_stream_fanout            => true,
           :enable_cancel_on_failover       => false,
         )
         should contain_oslo__messaging__notifications('octavia_config').with(
@@ -138,6 +149,7 @@ describe 'octavia' do
       end
 
       it 'configures various things' do
+        is_expected.to contain_octavia_config('DEFAULT/host').with_value('localhost')
         is_expected.to contain_octavia_config('oslo_messaging/topic').with_value('oct-rpc')
       end
     end
